@@ -3,15 +3,14 @@
 
 #pragma once
 
-#include "../openpgl.h"
+#include <string>
 
-#include "Region.h"
+#include "../openpgl.h"
 #include "Device.h"
-#include "SampleStorage.h"
 #include "FieldConfig.h"
 #include "FieldStatistics.h"
-
-#include <string>
+#include "Region.h"
+#include "SampleStorage.h"
 
 namespace openpgl
 {
@@ -34,23 +33,23 @@ struct Field
 {
     /**
      * @brief Creates a new guiding field.
-     * 
+     *
      * @param device The Device defining the compute architecture and optimization of the Field implementation.
      * @param args The configuration of the Field (e.g., spatial or directional representation).
      */
     Field(Device *device, const FieldConfig &args);
 
     /**
-     * @brief Creates/Loads a guiding field from a file. 
-     * 
+     * @brief Creates/Loads a guiding field from a file.
+     *
      * @param device The Device defining the compute architecture and optimization of the Field implementation.
      * @param fieldFileName The location of the file the Field is loaded from.
      */
-	Field(Device *device, const std::string& fieldFileName);
+    Field(Device *device, const std::string &fieldFileName);
 
     ~Field();
 
-    Field(const Field&) = delete;
+    Field(const Field &) = delete;
 
     /**
      * @brief Stores Field as serialized representation to file on disk
@@ -58,7 +57,7 @@ struct Field
      * @param fieldFileName path where to store serialized representation
      * @return if field could be stored to file
      */
-    bool Store(const std::string& fieldFileName) const;
+    bool Store(const std::string &fieldFileName) const;
 
     /**
      * @brief Sets the bounding box of the scenes.
@@ -70,15 +69,15 @@ struct Field
      * using the first sample batch.
      * @param bounds
      */
-    void SetSceneBounds(const pgl_box3f& bounds);
+    void SetSceneBounds(const pgl_box3f &bounds);
 
     /**
      * @brief Get the bounding box of the scene/
-     * 
+     *
      * The returned bounding box merges the bounds for the surface field and
      * the volume field.
-     * 
-     * @return pgl_box3f 
+     *
+     * @return pgl_box3f
      */
     pgl_box3f GetSceneBounds() const;
 
@@ -87,65 +86,66 @@ struct Field
      *
      * @param sampleStorage
      */
-    void Update(const SampleStorage& sampleStorage);
+    void Update(const SampleStorage &sampleStorage);
 
     /**
      * @brief Updates the current approximation of the surface radiance field.
      *
      * @param sampleStorage
      */
-    void UpdateSurface(const SampleStorage& sampleStorage);
+    void UpdateSurface(const SampleStorage &sampleStorage);
 
     /**
      * @brief Updates the current approximation of the volume radiance field.
      *
      * @param sampleStorage
      */
-    void UpdateVolume(const SampleStorage& sampleStorage);
+    void UpdateVolume(const SampleStorage &sampleStorage);
 
     void Reset();
 
     /// Returns the number of performed training iterations.
     size_t GetIteration() const;
 
-    /// Checks if the guiding information of the Field is valid (e.g., contains no invalid directional distributions). 
+    /// Checks if the guiding information of the Field is valid (e.g., contains no invalid directional distributions).
     bool Validate() const;
 
     /**
      * @brief Gets the statistics for the surface guiding Field.
-     * 
-     * @return FieldStatistics 
+     *
+     * @return FieldStatistics
      */
     FieldStatistics GetSurfaceStatistics() const;
 
     /**
      * @brief Gets the statistics for the volume guiding Field.
-     * 
-     * @return FieldStatistics 
+     *
+     * @return FieldStatistics
      */
     FieldStatistics GetVolumeStatistics() const;
-    
+
     /// Checks if the spatial structure and directional distribution of this Field are similar to the ones stored in another Field.
-    bool operator==(const Field& b) const;
+    bool operator==(const Field &b) const;
 
     friend struct openpgl::cpp::SurfaceSamplingDistribution;
     friend struct openpgl::cpp::VolumeSamplingDistribution;
-    private:
-        PGLField m_fieldHandle {nullptr};
+
+   private:
+    PGLField m_fieldHandle{nullptr};
 };
 
 ////////////////////////////////////////////////////////////
 /// Implementation
 ////////////////////////////////////////////////////////////
 
-OPENPGL_INLINE Field::Field(Device *device, const FieldConfig& cfg)
+OPENPGL_INLINE Field::Field(Device *device, const FieldConfig &cfg)
 {
     OPENPGL_ASSERT(device);
     OPENPGL_ASSERT(device->m_deviceHandle);
     m_fieldHandle = pglDeviceNewField(device->m_deviceHandle, cfg.m_args);
 }
 
-OPENPGL_INLINE Field::Field(Device *device, const std::string& fieldFileName)
+OPENPGL_INLINE Field::Field(Device *device, const std::string &fieldFileName)
 {
     OPENPGL_ASSERT(device);
     OPENPGL_ASSERT(device->m_deviceHandle);
@@ -161,7 +161,7 @@ OPENPGL_INLINE Field::~Field()
     m_fieldHandle = nullptr;
 }
 
-OPENPGL_INLINE bool Field::Store(const std::string& fieldFileName) const
+OPENPGL_INLINE bool Field::Store(const std::string &fieldFileName) const
 {
     OPENPGL_ASSERT(m_fieldHandle);
     return pglFieldStoreToFile(m_fieldHandle, fieldFileName.c_str());
@@ -173,7 +173,7 @@ OPENPGL_INLINE size_t Field::GetIteration() const
     return pglFieldGetIteration(m_fieldHandle);
 }
 
-OPENPGL_INLINE void Field::SetSceneBounds(const pgl_box3f& bounds)
+OPENPGL_INLINE void Field::SetSceneBounds(const pgl_box3f &bounds)
 {
     OPENPGL_ASSERT(m_fieldHandle);
     pglFieldSetSceneBounds(m_fieldHandle, bounds);
@@ -185,19 +185,19 @@ OPENPGL_INLINE pgl_box3f Field::GetSceneBounds() const
     return pglFieldGetSceneBounds(m_fieldHandle);
 }
 
-OPENPGL_INLINE void Field::Update(const SampleStorage& sampleStorage)
+OPENPGL_INLINE void Field::Update(const SampleStorage &sampleStorage)
 {
     OPENPGL_ASSERT(m_fieldHandle);
     pglFieldUpdate(m_fieldHandle, sampleStorage.m_sampleStorageHandle);
 }
 
-OPENPGL_INLINE void Field::UpdateSurface(const SampleStorage& sampleStorage)
+OPENPGL_INLINE void Field::UpdateSurface(const SampleStorage &sampleStorage)
 {
     OPENPGL_ASSERT(m_fieldHandle);
     pglFieldUpdateSurface(m_fieldHandle, sampleStorage.m_sampleStorageHandle);
 }
 
-OPENPGL_INLINE void Field::UpdateVolume(const SampleStorage& sampleStorage)
+OPENPGL_INLINE void Field::UpdateVolume(const SampleStorage &sampleStorage)
 {
     OPENPGL_ASSERT(m_fieldHandle);
     pglFieldUpdateVolume(m_fieldHandle, sampleStorage.m_sampleStorageHandle);
@@ -215,24 +215,26 @@ OPENPGL_INLINE bool Field::Validate() const
     return pglFieldValidate(m_fieldHandle);
 }
 
-OPENPGL_INLINE bool Field::operator==(const Field& b) const
+OPENPGL_INLINE bool Field::operator==(const Field &b) const
 {
     OPENPGL_ASSERT(m_fieldHandle);
     OPENPGL_ASSERT(b.m_fieldHandle);
     return pglFieldCompare(m_fieldHandle, b.m_fieldHandle);
 }
 
-OPENPGL_INLINE FieldStatistics Field::GetSurfaceStatistics() const{
+OPENPGL_INLINE FieldStatistics Field::GetSurfaceStatistics() const
+{
     OPENPGL_ASSERT(m_fieldHandle);
     PGLFieldStatistics fieldStats = pglFieldGetSurfaceStatistics(m_fieldHandle);
     return FieldStatistics(fieldStats);
 }
 
-OPENPGL_INLINE FieldStatistics Field::GetVolumeStatistics() const{
+OPENPGL_INLINE FieldStatistics Field::GetVolumeStatistics() const
+{
     OPENPGL_ASSERT(m_fieldHandle);
     PGLFieldStatistics fieldStats = pglFieldGetVolumeStatistics(m_fieldHandle);
     return FieldStatistics(fieldStats);
 }
 
-} // cpp
-} // openpgl
\ No newline at end of file
+}  // namespace cpp
+}  // namespace openpgl
\ No newline at end of file
